@@ -48,6 +48,14 @@ const navigation: PortalModule<NavigationState> = {
   actions: {
     setActiveButton({ commit, dispatch }, id) {
       dispatch('modal/hideAndClearModal', undefined, { root: true });
+      if (id === 'bell') {
+        dispatch('notifications/hideAllNotifications', undefined, { root: true });
+      }
+      if (id) {
+        dispatch('activity/setLevel', `header-${id}`, { root: true });
+      } else {
+        dispatch('activity/setLevel', 'portal', { root: true });
+      }
       commit('ACTIVEBUTTON', id);
     },
   },
